import typescript from '@rollup/plugin-typescript';
import {nodeResolve} from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import copy from 'rollup-plugin-copy';
import postcss from 'rollup-plugin-postcss'
import json from "@rollup/plugin-json";

const isProd = (process.env.BUILD === 'production');

const banner = 
`/*
THIS IS A GENERATED/BUNDLED FILE BY ROLLUP
if you want to view the source visit the plugins github repository
*/
`;

export default {
  input: './src/main.ts',
  output: {
    dir: './dist/',
    sourcemap: isProd ? 'hidden' : 'inline',
    sourcemapExcludeSources: isProd,
    format: 'cjs',
    exports: 'default',
    banner,
  },
  external: ['obsidian', 'electron'],
  plugins: [
    typescript(),
    nodeResolve({browser: true, preferBuiltins: true}),
    commonjs(),
    json(),
    postcss({
      plugins: []
    }),
    copy({
      targets: [
        { src: './manifest.json', dest: './dist/' },
        { src: './manifest-beta.json', dest: './dist/' },
        { src: './styles.css', dest: './dist/' }
      ], flatten: false
    })
  ]
};